package edu.neu.ccs.beans.demo.colorbeans;

import java.beans.*;
import java.lang.reflect.*;

import java.awt.*;

/**
 *
 * The purpose of this BeanInfo class is to define the properties eligible
 * for edit and to associate a property editor with the "background"
 * property.   
 * 
 */
public class ColorBeanContextBeanInfo extends SimpleBeanInfo {

   private final Class beanClass = ColorBeanContext.class;
   
   /**
	 * Gets a BeanInfo for the superclass of this bean.
	 *
	 * @return                BeanInfo[] containing this bean's superclass BeanInfo
	 */
   public BeanInfo[] getAdditionalBeanInfo()
   {
	   return new BeanInfo[0];
	   /*
	  try
	  {
		  BeanInfo[] bi = new BeanInfo[1];
		  bi[0] = Introspector.getBeanInfo(beanClass.getSuperclass());
		  return bi;
	  }
	  catch (IntrospectionException e)
	  {
		  throw new Error(e.toString());
	  }
	  */
   }      
   /**
	* Gets the BeanDescriptor for this bean.
	*
	* @return                 an object of type BeanDescriptor
	*
	*/
   public BeanDescriptor getBeanDescriptor()
   {
	  BeanDescriptor bd = new BeanDescriptor(beanClass);
	  return bd;
   }   
   /**
	 * Gets an image that may be used to visually represent this bean
	 * (in the toolbar, on a form, etc).
	 * @param   iconKind      the type of icon desired, one of: BeanInfo.ICON_MONO_16x16,
	 * BeanInfo.ICON_COLOR_16x16, BeanInfo.ICON_MONO_32x32, or BeanInfo.ICON_COLOR_32x32.
	 *
	 * @return                an image for this bean
	 * @see BeanInfo#ICON_MONO_16x16
	 * @see BeanInfo#ICON_COLOR_16x16
	 * @see BeanInfo#ICON_MONO_32x32
	 * @see BeanInfo#ICON_COLOR_32x32
	 */
   public Image getIcon(int iconKind) {
	  if (iconKind == BeanInfo.ICON_COLOR_16x16)
	  {
			Image img = loadImage("ColorBeanContext_1616.gif");
			return img;
	  }
	  
	  if (iconKind == BeanInfo.ICON_COLOR_32x32)
	  {
			Image img = loadImage("ColorBeanContext_3232.gif");
			return img;
	  }
	  
	  return null;
   }   
   /**
	* This method defines the property descriptors for the bean's
	* color.
	*
	* @return                 Array of property descriptors.
	*/
   public PropertyDescriptor[] getPropertyDescriptors() {

	  try {
		 PropertyDescriptor color = 
				new PropertyDescriptor("color",beanClass, "getColor","setColor");
				/*
		 PropertyDescriptor font =
				new PropertyDescriptor("font", beanClass);
		 PropertyDescriptor name =
				new PropertyDescriptor("name", beanClass);
				*/
		 color.setBound(true);
		 //font.setBound(true);
		 //name.setBound(true);
		 
		 PropertyDescriptor[] propList = {
			color//, font, name
		 };
		 
		 return propList;
	  }
	  catch (IntrospectionException e) {
		 return super.getPropertyDescriptors();
	  }
   }      
   /**
	* This is a convenience method for creating property descriptor objects.
	*
	* @param   name           Name of the property
	* @param   description    Descriptive string for the property
	*
	* @return                 Property descriptor object.
	*/
   private static PropertyDescriptor property(String name, String description)
					 throws IntrospectionException {


	  PropertyDescriptor p = new PropertyDescriptor(name, ColorBean.class);
	  p.setShortDescription(description);

	  return p;
   }   
} // end of class
